"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getOrCreateWebSocketClient = getOrCreateWebSocketClient;

var _reactNative = require("react-native");

var _isURL = _interopRequireDefault(require("validator/es/lib/isURL"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const {
  WebSocketClient: NativeWebSocketClient
} = _reactNative.NativeModules;
const Emitter = new _reactNative.NativeEventEmitter(NativeWebSocketClient);
const {
  EVENTS,
  READY_STATE
} = NativeWebSocketClient.getConstants();
const CLIENTS = {};
/**
 * Configurable WebSocket client
 */

class WebSocketClient {
  constructor(url) {
    _defineProperty(this, "url", void 0);

    _defineProperty(this, "readyState", void 0);

    _defineProperty(this, "onReadyStateSubscription", void 0);

    _defineProperty(this, "onWebSocketOpenSubscription", void 0);

    _defineProperty(this, "onWebSocketCloseSubscription", void 0);

    _defineProperty(this, "onWebSocketErrorSubscription", void 0);

    _defineProperty(this, "onWebSocketMessageSubscription", void 0);

    _defineProperty(this, "onWebSocketClientErrorSubscription", void 0);

    _defineProperty(this, "open", () => NativeWebSocketClient.connectFor(this.url));

    _defineProperty(this, "close", () => {
      this.readyState = READY_STATE.CLOSED;
      return NativeWebSocketClient.disconnectFor(this.url);
    });

    _defineProperty(this, "send", data => NativeWebSocketClient.sendDataFor(this.url, data));

    _defineProperty(this, "onOpen", callback => {
      if (this.onWebSocketOpenSubscription) {
        this.onWebSocketOpenSubscription.remove();
      }

      this.onWebSocketOpenSubscription = Emitter.addListener(EVENTS.OPEN_EVENT, event => {
        if (event.url === this.url && callback) {
          callback(event);
        }
      });
    });

    _defineProperty(this, "onClose", callback => {
      if (this.onWebSocketCloseSubscription) {
        this.onWebSocketCloseSubscription.remove();
      }

      this.onWebSocketCloseSubscription = Emitter.addListener(EVENTS.CLOSE_EVENT, event => {
        if (event.url === this.url && callback) {
          callback(event);
        }
      });
    });

    _defineProperty(this, "onError", callback => {
      if (this.onWebSocketErrorSubscription) {
        this.onWebSocketErrorSubscription.remove();
      }

      this.onWebSocketErrorSubscription = Emitter.addListener(EVENTS.ERROR_EVENT, event => {
        if (event.url === this.url && callback) {
          callback(event);
        }
      });
    });

    _defineProperty(this, "onMessage", callback => {
      if (this.onWebSocketMessageSubscription) {
        this.onWebSocketMessageSubscription.remove();
      }

      this.onWebSocketMessageSubscription = Emitter.addListener(EVENTS.MESSAGE_EVENT, event => {
        if (event.url === this.url && callback) {
          callback(event);
        }
      });
    });

    _defineProperty(this, "onClientError", callback => {
      if (this.onWebSocketClientErrorSubscription) {
        this.onWebSocketClientErrorSubscription.remove();
      }

      this.onWebSocketClientErrorSubscription = Emitter.addListener(EVENTS.ERROR_EVENT, event => {
        if (event.url === this.url) {
          callback(event);
        }
      });
    });

    _defineProperty(this, "invalidate", () => {
      var _this$onWebSocketOpen, _this$onWebSocketClos, _this$onWebSocketErro, _this$onWebSocketMess, _this$onWebSocketClie;

      this.onReadyStateSubscription.remove();
      (_this$onWebSocketOpen = this.onWebSocketOpenSubscription) === null || _this$onWebSocketOpen === void 0 ? void 0 : _this$onWebSocketOpen.remove();
      (_this$onWebSocketClos = this.onWebSocketCloseSubscription) === null || _this$onWebSocketClos === void 0 ? void 0 : _this$onWebSocketClos.remove();
      (_this$onWebSocketErro = this.onWebSocketErrorSubscription) === null || _this$onWebSocketErro === void 0 ? void 0 : _this$onWebSocketErro.remove();
      (_this$onWebSocketMess = this.onWebSocketMessageSubscription) === null || _this$onWebSocketMess === void 0 ? void 0 : _this$onWebSocketMess.remove();
      (_this$onWebSocketClie = this.onWebSocketClientErrorSubscription) === null || _this$onWebSocketClie === void 0 ? void 0 : _this$onWebSocketClie.remove();
      delete CLIENTS[this.url];
      return NativeWebSocketClient.invalidateClientFor(this.url);
    });

    this.url = url;
    this.readyState = READY_STATE.CLOSED;
    this.onReadyStateSubscription = Emitter.addListener(EVENTS.READY_STATE_EVENT, event => {
      if (event.url === this.url) {
        this.readyState = event.message;
      }
    });
  }

}

async function getOrCreateWebSocketClient(url) {
  let config = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  let clientErrorEventHandler = arguments.length > 2 ? arguments[2] : undefined;

  if (!isValidWebSocketURL(url)) {
    throw new Error(`"${url}" is not a valid WebSocket URL`);
  }

  let created = false;
  let client = CLIENTS[url];

  if (!client) {
    created = true;
    client = new WebSocketClient(url);

    if (clientErrorEventHandler) {
      client.onClientError(clientErrorEventHandler);
    }

    await NativeWebSocketClient.createClientFor(url, config);
    CLIENTS[url] = client;
  }

  return {
    client,
    created
  };
}

const isValidWebSocketURL = url => {
  return (0, _isURL.default)(url, {
    protocols: ["ws", "wss"],
    require_protocol: true,
    require_valid_protocol: true,
    require_host: true
  });
};
//# sourceMappingURL=index.js.map