import type { ClientHeaders, ClientP12Configuration } from "./APIClient";
import type { WebSocketReadyState } from "./NativeWebSocketClient";
export declare type WebSocketClientConfiguration = {
    headers?: ClientHeaders;
    timeoutInterval?: number;
    enableCompression?: boolean;
    clientP12Configuration?: ClientP12Configuration;
    trustSelfSignedServerCertificate?: boolean;
};
declare type WebSocketMessage = string | WebSocketReadyState | Record<string, string | number>;
export declare type WebSocketEvent = {
    url: string;
    message: WebSocketMessage;
};
export declare type WebSocketEventHandler = (event: WebSocketEvent) => void;
export declare type WebSocketClientErrorEventHandler = (event: WebSocketClientErrorEvent) => void;
export interface WebSocketClientInterface {
    url: string;
    readyState: WebSocketReadyState;
    onReadyStateSubscription: EmitterSubscription;
    onWebSocketOpenSubscription?: EmitterSubscription;
    onWebSocketCloseSubscription?: EmitterSubscription;
    onWebSocketErrorSubscription?: EmitterSubscription;
    onWebSocketMessageSubscription?: EmitterSubscription;
    onWebSocketClientErrorSubscription?: EmitterSubscription;
    send(data: string): void;
    open(): void;
    close(): void;
    onOpen(callback: WebSocketEventHandler): void;
    onClose(callback: WebSocketEventHandler): void;
    onError(callback: WebSocketEventHandler): void;
    onMessage(callback: WebSocketEventHandler): void;
    onClientError(callback: WebSocketClientErrorEventHandler): void;
    invalidate(): Promise<void>;
}
export declare type WebSocketClientErrorEvent = {
    url: string;
    errorCode: number;
    errorDescription: string;
};
export {};
